package Bundle::dualLived;

use strict;

$Bundle::dualLived::VERSION = '0.00_06';

1;

__END__

=head1 NAME

Bundle::dualLived - Update core dualLived modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::dualLived'

=head1 CONTENTS

autodie

base

bigint

constant

encoding

encoding::warnings

if

lib

parent

threads

threads::shared

version

Test::Harness

Archive::Extract

Archive::Tar

Attribute::Handlers

AutoLoader

B::Debug

B::Lint

CGI

CPAN

CPAN::Meta

CPAN::Meta::YAML

CPANPLUS

CPANPLUS::Dist::Build

Compress::Raw::Bzip2

Compress::Raw::Zlib

Compress::Zlib

Cwd

DB_File

Data::Dumper

Devel::InnerPackage

Devel::PPPort

Digest
 
Digest::MD5

Digest::SHA

Exporter

ExtUtils::CBuilder

ExtUtils::Command

ExtUtils::MakeMaker

ExtUtils::Constant::Base

ExtUtils::Install

ExtUtils::Manifest

ExtUtils::ParseXS

File::Fetch

File::Path

File::Temp

Text::Balanced

Filter::Simple

Filter::Util::Call

Getopt::Long

HTTP::Tiny

I18N::LangTags

IO

IO::Compress::Base

IO::Zlib

IPC::Cmd

IPC::Msg

JSON::PP

List::Util

Locale::Constants

Locale::Maketext

Locale::Maketext::Simple

Log::Message

MIME::Base64

Math::BigInt

Math::BigInt::FastCalc

Math::BigRat

Math::Complex

Memoize

Module::Build

Module::CoreList

Module::Load

Module::Load::Conditional

Module::Loaded

Module::Metadata

Module::Pluggable

NEXT

Net::Cmd

Package::Constants

Params::Check

Parse::CPAN::Meta

Perl::OSType

PerlIO::via::QuotedPrint

Pod::Checker

Pod::Escapes

Pod::LaTeX

Pod::Man

Pod::Perldoc

Pod::Simple

Pod::Usage

Safe

SelfLoader

Shell

Storable

Sys::Syslog

Term::ANSIColor

Term::Cap

Term::UI

Test

Test::Simple

Text::Balanced

Text::ParseWords

Text::Soundex

Text::Tabs

Thread::Queue

Thread::Semaphore

Tie::File

Tie::RefHash

Time::HiRes

Time::Local

Time::Piece

Unicode::Collate

Unicode::Normalize

Version::Requirements

Win32

Win32API::File

XSLoader

=head1 AUTHOR

Version 0.00_06 Kevin W. Henwood, <Khen1950fx@aol.com>

head1 COPYRIGHT AND LICENSE

Copyright (C) 2010, 2011 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.

=cut

1;
